@@ -19,7 +19,7 @@
  * @package log4php
  * @author     Marco Vassura
  * @license    http://www.apache.org/licenses/LICENSE-2.0 Apache License, Version 2.0
- * @version    SVN: $Id: Logger.php 635069 2008-03-08 20:19:11Z carnold $
+ * @version    SVN: $Id: Logger.php 663206 2008-06-04 15:27:16Z carnold $
  * @link       http://logging.apache.org/log4php
  */
 
@@ -37,7 +37,7 @@ require_once(LOG4PHP_DIR . '/spi/LoggerLoggingEvent.php');
  * This class has been deprecated and replaced by the Logger subclass.
  *
  * @author       Marco Vassura
- * @version      $Revision: 635069 $
+ * @version      $Revision: 663206 $
  * @package log4php
  * @see Logger
  */
@@ -507,7 +507,7 @@ class Logger {
      */
     public function removeAppender($appender)
     {
-        if (is_a($appender, 'loggerappender')) {
+        if ($appender instanceof LoggerAppender) {
             $appender->close();
             unset($this->aai[$appender->getName()]);
         } elseif (is_string($appender) and isset($this->aai[$appender])) {
